@@ -13,7 +13,7 @@ def get_x_title(tag: str) -> str:
     :param tag: The tag logged in tensoboard.
     """
 
-    if "timesteps" in tag or "success" in tag:
+    if "reward" in tag or "success" in tag:
         return "Timesteps"
     else:
         return "Updates"
@@ -61,7 +61,7 @@ def draw_line(
             color = _hex_to_rgba_string(color, 0.3)
         else:
             color = _str_rgb_color_to_rgba_str(color, 0.3)
-        print(max_reward)
+
         mean_plus_std = go.Scatter(
             x=experiment_df.index,
             y=(experiment_df["mean"] + experiment_df["std"]).clip(upper=1 if max_reward is None else max_reward),
@@ -147,6 +147,7 @@ def separate_exps(experiments_df: pd.DataFrame, tags: List[str]) -> Dict[str, pd
         # multiple experiments
         run_col_vals = set([name_run.split("/")[0] for name_run in experiments_df.run.unique()])
         multiple = True
+
     for run_col_val in run_col_vals:
         experiment_df = exp_df_to_tags_df(
             experiments_df[
@@ -209,7 +210,7 @@ def update_layout(fig: go.Figure, title: str, y_title: str) -> go.Figure:
         yaxis_title=y_title,
         title_x=0.5,
         showlegend=True,
-        font=dict(family="Courier New, monospace", size=15),
+        font=dict(family="Courier New, monospace", size=24),
     )
 
     return fig
