@@ -1,4 +1,3 @@
-from gc import callbacks
 import os
 import json
 import click
@@ -101,7 +100,7 @@ def upload(ctx, path, name):
             # first time interacting with tensorboard
             return_str = subprocess.run(comm, text=True, input="yes", capture_output=True).stdout
         else:
-            return_str = subprocess.run(comm, capture_output=True).stdout
+            return_str = subprocess.run(comm, text=True, capture_output=True).stdout
         exp_id = return_str.split("\n")[-2].split()[-1].split("/")[-2]
         data = {
             "date": pd.Series([datetime.date.today().strftime("%d%m%y")], dtype=str),
@@ -186,12 +185,13 @@ def download(ctx, name):
     default="line",
 )
 @click.option(
-    "--max_reward",
+    "--max-reward",
     type=click.INT,
     help="Denotes the max reward achievable in the env the model was trained when"
     "calculating variance for envs evaluating reward rather than success",
 )
-def plot(ctx, name, tags, models, compare, variance, plot_type, max_reward):
+@click.option("--file-name", type=click.STRING, help="The name of the file to save the image in.")
+def plot(ctx, name, tags, models, compare, variance, plot_type, max_reward, file_name):
     """
     Plots the data in the csv file identified by PATH.
 
@@ -238,8 +238,13 @@ def plot(ctx, name, tags, models, compare, variance, plot_type, max_reward):
                 if ctx.obj["vis"]:
                     fig.show()
                 if ctx.obj["save"]:
+                    filename = (
+                        f"{exp_name}_{'_'.join(tag)}{'_variance' if variance else ''}.png"
+                        if not file_name
+                        else f"{file_name}_{'_'.join(tag)}{'_variance' if variance else ''}.png"
+                    )
                     fig.write_image(
-                        os.path.join(exp_path, f"{exp_name}_{'_'.join(tag)}{'_variance' if variance else ''}.png"),
+                        os.path.join(exp_path, filename),
                         width=2000,
                         height=1000,
                         scale=1,
@@ -251,11 +256,18 @@ def plot(ctx, name, tags, models, compare, variance, plot_type, max_reward):
             if ctx.obj["vis"]:
                 fig.show()
             if ctx.obj["save"]:
+                filename = (
+                    (
+                        f"{'_'.join(models) if len(models) != total_models else 'all'}_{'_'.join(tag)}"
+                        + f"{'_variance' if variance else ''}.png"
+                    )
+                    if not file_name
+                    else f"{file_name}_{'_'.join(tag)}{'_variance' if variance else ''}.png"
+                )
                 fig.write_image(
                     os.path.join(
                         exp_path,
-                        f"{'_'.join(models) if len(models) != total_models else 'all'}_{'_'.join(tag)}"
-                        "{'_variance' if variance else ''}.png",
+                        filename,
                     ),
                     width=2000,
                     height=1000,
@@ -284,7 +296,7 @@ def embedding(ctx, path, comps, label, points, title):
         k: col
         for k, col in zip(
             unique,
-            random.sample(ctx.obj["colors"]["qualitative"], len(embedding_df[label].unique())),
+            random.sample(ctx.obj["colors"]["qualitative"], len(unique)),
         )
     }
     traces = []
@@ -296,9 +308,8 @@ def embedding(ctx, path, comps, label, points, title):
         traces.append(DRAW_FN_MAP["scatter"](comp_label_df, comps, color, comp_label))
 
     fig = go.Figure(traces)
-    # if ctx.obj["save"]:
-    #     fig = ax.get_figure()
-    #     fig.savefig(f"{tag}.png")
+    if ctx.obj["save"]:
+        fig.write_image(os.path.join(os.path.dirname(path), f"{len(comps)}D_{label}.png"))
     fig = update_layout(fig, title, comps[0], comps[1])
     if ctx.obj["vis"]:
         fig.show()
